@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 import os
 import sys
-from image2dia import image2dia
+from image2dia import Image2Dia
 
 def Error(nom):
     """ 
@@ -20,7 +20,7 @@ def Error(nom):
 
 
 # -- MAIN -- 
-i2d = image2dia.Image2Dia()
+i2d = Image2Dia()
 # Always show the version info
 print "%s v.%s" % (os.path.basename(sys.argv[0]), i2d.getVersion())
 print "-----------------------------------"
